import { Chain, LayoutToType, Network, Platform, PlatformToChains } from "@wormhole-foundation/sdk-base";
import { AccountAddress, ChainAddress } from "../address";
import { CircleMessageId } from "../attestation";
import "../payloads/connect";
import { TokenId } from "../types";
import { UnsignedTransaction } from "../unsignedTransaction";
export declare const circleMessageLayout: readonly [{
    readonly binary: "uint";
    readonly size: 4;
    readonly custom: 0;
    readonly omit: true;
    readonly name: "version";
}, {
    readonly binary: "uint";
    readonly size: 4;
    readonly custom: {
        to: (id: number) => "Solana" | "Ethereum" | "Avalanche" | "Arbitrum" | "Optimism" | "Base";
        from: (name: "Solana" | "Ethereum" | "Avalanche" | "Arbitrum" | "Optimism" | "Base") => 0 | 1 | 2 | 3 | 5 | 6;
    };
    readonly name: "sourceDomain";
}, {
    readonly binary: "uint";
    readonly size: 4;
    readonly custom: {
        to: (id: number) => "Solana" | "Ethereum" | "Avalanche" | "Arbitrum" | "Optimism" | "Base";
        from: (name: "Solana" | "Ethereum" | "Avalanche" | "Arbitrum" | "Optimism" | "Base") => 0 | 1 | 2 | 3 | 5 | 6;
    };
    readonly name: "destinationDomain";
}, {
    readonly binary: "uint";
    readonly size: 8;
    readonly name: "nonce";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("..").UniversalAddress;
        from: (val: import("..").UniversalAddress) => Uint8Array;
    };
    readonly name: "sender";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("..").UniversalAddress;
        from: (val: import("..").UniversalAddress) => Uint8Array;
    };
    readonly name: "recipient";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("..").UniversalAddress;
        from: (val: import("..").UniversalAddress) => Uint8Array;
    };
    readonly name: "destinationCaller";
}, {
    readonly name: "payload";
    readonly binary: "object";
    readonly layout: readonly [{
        readonly binary: "uint";
        readonly size: 4;
        readonly custom: 0;
        readonly omit: true;
        readonly name: "messageBodyVersion";
    }, {
        readonly binary: "bytes";
        readonly size: 32;
        readonly custom: {
            to: (val: Uint8Array) => import("..").UniversalAddress;
            from: (val: import("..").UniversalAddress) => Uint8Array;
        };
        readonly name: "burnToken";
    }, {
        readonly binary: "bytes";
        readonly size: 32;
        readonly custom: {
            to: (val: Uint8Array) => import("..").UniversalAddress;
            from: (val: import("..").UniversalAddress) => Uint8Array;
        };
        readonly name: "mintRecipient";
    }, {
        readonly binary: "uint";
        readonly size: 32;
        readonly name: "amount";
    }, {
        readonly binary: "bytes";
        readonly size: 32;
        readonly custom: {
            to: (val: Uint8Array) => import("..").UniversalAddress;
            from: (val: import("..").UniversalAddress) => Uint8Array;
        };
        readonly name: "messageSender";
    }];
}];
export type CircleMessage = LayoutToType<typeof circleMessageLayout>;
export declare const deserializeCircleMessage: (data: Uint8Array) => [CircleMessage, string];
export declare const serializeCircleMessage: (msg: CircleMessage) => Uint8Array;
export type CircleTransferMessage = {
    from: ChainAddress;
    to: ChainAddress;
    token: TokenId;
    amount: bigint;
    message: CircleMessage;
    id: CircleMessageId;
};
export type CircleTransferDetails = {
    amount: bigint;
    from: ChainAddress;
    to: ChainAddress;
    automatic?: boolean;
    payload?: Uint8Array;
    nativeGas?: bigint;
};
export declare function isCircleTransferDetails(thing: any): thing is CircleTransferDetails;
export interface AutomaticCircleBridge<N extends Network, P extends Platform, C extends Chain = PlatformToChains<P>> {
    getRelayerFee(destination: Chain): Promise<bigint>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, amount: bigint, nativeGas?: bigint): AsyncGenerator<UnsignedTransaction<N, C>>;
}
export interface CircleBridge<N extends Network, P extends Platform, C extends PlatformToChains<P>> {
    redeem(sender: AccountAddress<C>, message: CircleMessage, attestation: string): AsyncGenerator<UnsignedTransaction<N, C>>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, amount: bigint): AsyncGenerator<UnsignedTransaction<N, C>>;
    parseTransactionDetails(txid: string): Promise<CircleTransferMessage>;
}
//# sourceMappingURL=cctp.d.ts.map